# archimedean

Sends email whenever there is new homework on Archie website. Can download all files from any class in CineMath. Can download any resource posted on Archie. 
Still in testing phase.

## Installation

    pip install archimedean

## Usage

    usage stuff